==> stree-0.0.11.tar.gz: stree-0.0.11/CHANGELOG.md <==
# Changelog

## [v0.0.11](https://github.com/orangekame3/stree/compare/v0.0.10...v0.0.11) - 2023-10-01

- add CODEOWNERS by @orangekame3 in <https://github.com/orangekame3/stree/pull/21>
- add credits by @orangekame3 in <https://github.com/orangekame3/stree/pull/22>
- respect environment variables same as AWS CLI. by @fujiwara in <https://github.com/orangekame3/stree/pull/19>
- gtree パッケージの更新 by @ddddddO in <https://github.com/orangekame3/stree/pull/24>
- -level (-L) Option for Limit max depth by @mashiike in <https://github.com/orangekame3/stree/pull/23>
- impl MFA by @ddddddO in <https://github.com/orangekame3/stree/pull/25>
- update readme for release v0.0.11 by @orangekame3 in <https://github.com/orangekame3/stree/pull/26>
- add article by @orangekame3 in <https://github.com/orangekame3/stree/pull/27>

## [v0.0.10](https://github.com/orangekame3/stree/compare/v0.0.9...v0.0.10) - 2023-09-15

## [v0.0.9](https://github.com/orangekame3/stree/compare/v0.0.8...v0.0.9) - 2023-09-15

- read profile region by @orangekame3 in <https://github.com/orangekame3/stree/pull/12>
- add version file by @orangekame3 in <https://github.com/orangekame3/stree/pull/14>

## [v0.0.8](https://github.com/orangekame3/stree/compare/v0.0.7...v0.0.8) - 2023-09-13

- skip adding node when empty path by @orangekame3 in <https://github.com/orangekame3/stree/pull/10>

## [v0.0.7](https://github.com/orangekame3/stree/compare/v0.0.6...v0.0.7) - 2023-09-13

## [v0.0.6](https://github.com/orangekame3/stree/compare/v0.0.5...v0.0.6) - 2023-09-13

- Add mega-linter by @orangekame3 in <https://github.com/orangekame3/stree/pull/7>

## [v0.0.5](https://github.com/orangekame3/stree/compare/v0.0.4...v0.0.5) - 2023-09-12

## [v0.0.4](https://github.com/orangekame3/stree/compare/v0.0.3...v0.0.4) - 2023-09-12

## [v0.0.3](https://github.com/orangekame3/stree/compare/v0.0.2...v0.0.3) - 2023-09-12

## [v0.0.2](https://github.com/orangekame3/stree/compare/v0.0.1...v0.0.2) - 2023-09-12

## [v0.0.1](https://github.com/orangekame3/stree/commits/v0.0.1) - 2023-09-12

==> stree-0.0.12.tar.gz: stree-0.0.12/CHANGELOG.md <==
# Changelog

## [v0.0.12](https://github.com/orangekame3/stree/compare/v0.0.11...v0.0.12) - 2023-11-18
- Update README.md by @orangekame3 in https://github.com/orangekame3/stree/pull/28
- Modify warning by @ddddddO in https://github.com/orangekame3/stree/pull/31
- Fix region and endpoint overrides by @lusingander in https://github.com/orangekame3/stree/pull/30

## [v0.0.11](https://github.com/orangekame3/stree/compare/v0.0.10...v0.0.11) - 2023-10-01

- add CODEOWNERS by @orangekame3 in <https://github.com/orangekame3/stree/pull/21>
- add credits by @orangekame3 in <https://github.com/orangekame3/stree/pull/22>
- respect environment variables same as AWS CLI. by @fujiwara in <https://github.com/orangekame3/stree/pull/19>
- gtree パッケージの更新 by @ddddddO in <https://github.com/orangekame3/stree/pull/24>
- -level (-L) Option for Limit max depth by @mashiike in <https://github.com/orangekame3/stree/pull/23>
- impl MFA by @ddddddO in <https://github.com/orangekame3/stree/pull/25>
- update readme for release v0.0.11 by @orangekame3 in <https://github.com/orangekame3/stree/pull/26>
- add article by @orangekame3 in <https://github.com/orangekame3/stree/pull/27>

## [v0.0.10](https://github.com/orangekame3/stree/compare/v0.0.9...v0.0.10) - 2023-09-15

## [v0.0.9](https://github.com/orangekame3/stree/compare/v0.0.8...v0.0.9) - 2023-09-15

- read profile region by @orangekame3 in <https://github.com/orangekame3/stree/pull/12>
- add version file by @orangekame3 in <https://github.com/orangekame3/stree/pull/14>

## [v0.0.8](https://github.com/orangekame3/stree/compare/v0.0.7...v0.0.8) - 2023-09-13

- skip adding node when empty path by @orangekame3 in <https://github.com/orangekame3/stree/pull/10>

## [v0.0.7](https://github.com/orangekame3/stree/compare/v0.0.6...v0.0.7) - 2023-09-13

## [v0.0.6](https://github.com/orangekame3/stree/compare/v0.0.5...v0.0.6) - 2023-09-13

- Add mega-linter by @orangekame3 in <https://github.com/orangekame3/stree/pull/7>

## [v0.0.5](https://github.com/orangekame3/stree/compare/v0.0.4...v0.0.5) - 2023-09-12

## [v0.0.4](https://github.com/orangekame3/stree/compare/v0.0.3...v0.0.4) - 2023-09-12

## [v0.0.3](https://github.com/orangekame3/stree/compare/v0.0.2...v0.0.3) - 2023-09-12

## [v0.0.2](https://github.com/orangekame3/stree/compare/v0.0.1...v0.0.2) - 2023-09-12

## [v0.0.1](https://github.com/orangekame3/stree/commits/v0.0.1) - 2023-09-12
